
/* Chrysalide - Outil d'analyse de fichiers binaires
 * restricted.c - prototypes pour l'équivalent Python du fichier "analysis/contents/restricted.c"
 *
 * Copyright (C) 2015 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  OpenIDA is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  OpenIDA is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#include "restricted.h"


#include <pygobject.h>


#include <i18n.h>


#include <analysis/contents/restricted.h>


#include "../content.h"
#include "../../arch/vmpa.h"



/* Crée un nouvel objet Python de type 'BinContent'. */
static PyObject *py_restricted_content_new(PyTypeObject *, PyObject *, PyObject *);



/******************************************************************************
*                                                                             *
*  Paramètres  : type = type de l'objet à instancier.                         *
*                args = arguments fournis à l'appel.                          *
*                kwds = arguments de type key=val fournis.                    *
*                                                                             *
*  Description : Crée un nouvel objet Python de type 'BinContent'.            *
*                                                                             *
*  Retour      : Instance Python mise en place.                               *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

static PyObject *py_restricted_content_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
{
    PyObject *result;                       /* Instance à retourner        */
    PyObject *content_obj;                  /* Objet pour le contenu       */
    PyObject *range_obj;                    /* Objet pour la restriction   */
    int ret;                                /* Bilan de lecture des args.  */
    GBinContent *content;                   /* Instance GLib correspondante*/
    mrange_t *range;                        /* Restriction à appliquer     */
    GBinContent *restricted;                /* Création GLib à transmettre */

    ret = PyArg_ParseTuple(args, "OO", &content_obj, &range_obj);
    if (!ret) return NULL;

    ret = PyObject_IsInstance(content_obj, (PyObject *)get_python_binary_content_type());
    if (!ret)
    {
        PyErr_SetString(PyExc_TypeError, _("The first argument must be an instance of BinContent."));
        return NULL;
    }

    ret = PyObject_IsInstance(range_obj, (PyObject *)get_python_mrange_type());
    if (!ret)
    {
        PyErr_SetString(PyExc_TypeError, _("The second argument must be an instance of mrange."));
        return NULL;
    }

    content = G_BIN_CONTENT(pygobject_get(content_obj));

    range = get_internal_mrange(range_obj);

    restricted = g_restricted_content_new(content, range);

    result = pygobject_new(G_OBJECT(restricted));

    return result;

}


/******************************************************************************
*                                                                             *
*  Paramètres  : -                                                            *
*                                                                             *
*  Description : Fournit un accès à une définition de type à diffuser.        *
*                                                                             *
*  Retour      : Définition d'objet pour Python.                              *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/



PyMethodDef py_restricted_content_methods[] = {
    { NULL }
};

PyGetSetDef py_restricted_content_getseters[] = {
    { NULL }
};

PyTypeObject py_restricted_content_type = {

    PyVarObject_HEAD_INIT(NULL, 0)

    .tp_name        = "pychrysalide.analysis.contents.RestrictedContent",
    .tp_basicsize   = sizeof(PyGObject),

    .tp_flags       = Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE,

    .tp_doc         = "PyChrysalide binary restricted content",

    /*
      .tp_methods     = py_restricted_content_methods,
      .tp_getset      = py_restricted_content_getseters,
      .tp_new         = (newfunc)py_restricted_content_new
    */
    .tp_new         = (newfunc)py_restricted_content_new

};



PyTypeObject *get_python_restricted_content_type(void)
{
#if 0
    static PyMethodDef py_restricted_content_methods[] = {
        { NULL }
    };

    static PyGetSetDef py_restricted_content_getseters[] = {
        { NULL }
    };

    static PyTypeObject py_restricted_content_type = {

        PyVarObject_HEAD_INIT(NULL, 0)

        .tp_name        = "pychrysalide.analysis.contents.RestrictedContent",
        .tp_basicsize   = sizeof(PyGObject),

        .tp_flags       = Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | 1 << 9,

        .tp_doc         = "PyChrysalide binary restricted content",

        /*
        .tp_methods     = py_restricted_content_methods,
        .tp_getset      = py_restricted_content_getseters,
        .tp_new         = (newfunc)py_restricted_content_new
        */

    };
#endif
    return &py_restricted_content_type;

}


/******************************************************************************
*                                                                             *
*  Paramètres  : module = module dont la définition est à compléter.          *
*                                                                             *
*  Description : Prend en charge l'objet 'pychrysalide.glibext.BinContent'.   *
*                                                                             *
*  Retour      : Bilan de l'opération.                                        *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/
#include "../content.h"//////////////////////////////////////////
bool register_python_restricted_content(PyObject *module)
{
    PyTypeObject *py_restricted_content_type;   /* Type Python 'BinContent'    */
    int ret;                                /* Bilan d'un appel            */
    PyObject *dict;                         /* Dictionnaire du module      */

    py_restricted_content_type = get_python_restricted_content_type();

    //py_restricted_content_type->tp_base = &PyGObject_Type;
    //py_restricted_content_type->tp_basicsize = py_restricted_content_type->tp_base->tp_basicsize;

    /*
    if (PyType_Ready(py_restricted_content_type) != 0)
        return false;
    */

    /*
    Py_INCREF(py_restricted_content_type);
    ret = PyModule_AddObject(module, "RestrictedContent", (PyObject *)py_restricted_content_type);
    if (ret != 0) return false;
    */

    dict = PyModule_GetDict(module);
    pygobject_register_class(dict, "RestrictedContent", G_TYPE_RESTRICTED_CONTENT, py_restricted_content_type,
                             Py_BuildValue("(O)", &PyGObject_Type/*py_restricted_content_type->tp_base*/,
                                   get_python_binary_content_type()));

    /*
    if (PyType_Ready(py_restricted_content_type) != 0)
        return false;
    */


    return true;

}
