
/* Chrysalide - Outil d'analyse de fichiers binaires
 * blockview.c - prototypes pour l'équivalent Python du fichier "gtkext/gtkblockview.c"
 *
 * Copyright (C) 2012 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  OpenIDA is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  OpenIDA is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#include "blockview.h"


#include <pygobject.h>


#include <gtkext/gtkblockview.h>


#include "bufferview.h"



/******************************************************************************
*                                                                             *
*  Paramètres  : -                                                            *
*                                                                             *
*  Description : Fournit un accès à une définition de type à diffuser.        *
*                                                                             *
*  Retour      : Définition d'objet pour Python.                              *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

PyTypeObject *get_python_block_view_type(void)
{
    static PyMethodDef py_block_view_methods[] = {
        { NULL }
    };

    static PyGetSetDef py_block_view_getseters[] = {
        { NULL }
    };

    static PyTypeObject py_block_view_type = {

        PyVarObject_HEAD_INIT(NULL, 0)

        .tp_name        = "pychrysalide.gtkext.BlockView",
        .tp_basicsize   = sizeof(PyGObject),

        .tp_flags       = Py_TPFLAGS_DEFAULT,

        .tp_doc         = "PyChrysalide block view.",

        .tp_methods     = py_block_view_methods,
        .tp_getset      = py_block_view_getseters

    };

    return &py_block_view_type;

}


/******************************************************************************
*                                                                             *
*  Paramètres  : module = module dont la définition est à compléter.          *
*                                                                             *
*  Description : Prend en charge l'objet 'pychrysalide.gtkext.BlockView'.     *
*                                                                             *
*  Retour      : Bilan de l'opération.                                        *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

bool register_python_block_view(PyObject *module)
{
    PyTypeObject *py_block_view_type;       /* Type Python 'BlockView'     */
    int ret;                                /* Bilan d'un appel            */
    PyObject *dict;                         /* Dictionnaire du module      */

    py_block_view_type = get_python_block_view_type();

    py_block_view_type->tp_base = get_python_buffer_view_type();
    py_block_view_type->tp_basicsize = py_block_view_type->tp_base->tp_basicsize;

    if (PyType_Ready(py_block_view_type) != 0)
        return false;

    Py_INCREF(py_block_view_type);
    ret = PyModule_AddObject(module, "BlockView", (PyObject *)py_block_view_type);
    if (ret != 0) return false;

    dict = PyModule_GetDict(module);
    pygobject_register_class(dict, "BlockView", GTK_TYPE_BLOCK_VIEW, py_block_view_type,
                             Py_BuildValue("(O)", py_block_view_type->tp_base));

    return true;

}
